@@ -42,9 +42,9 @@
 #'   proteome (search hit) and contains informations pertinent to that proteome.
 #'
 #' @references \itemize{
-#'   \item The UniProt Consortium, UniProt: the universal protein
-#'   knowledgebase in 2021, Nucleic Acids Research, Volume 49, Issue D1,
-#'   8 January 2021, Pages D480–D489, https://doi.org/10.1093/nar/gkaa1100
+#'   \item The UniProt Consortium , UniProt: the Universal Protein
+#'   Knowledgebase in 2025, Nucleic Acids Research, 2024;, gkae1010,
+#'   https://doi.org/10.1093/nar/gkae1010
 #'   \item Andrew Nightingale, Ricardo Antunes, Emanuele Alpi, Borisas
 #'   Bursteinas, Leonardo Gonzales, Wudong Liu, Jie Luo, Guoying Qi, Edd
 #'   Turner, Maria Martin, The Proteins API: accessing key integrated protein
@@ -83,83 +83,61 @@ rba_uniprot_proteomes_search <- function(name = NULL,
                                          ...) {
   ## Load Global Options
   .rba_ext_args(...)
+
   ## Check User-input Arguments
-  .rba_args(cons = list(list(arg = "upid",
-                             class = "character",
-                             max_len = 100),
-                        list(arg = "name",
-                             class = "character"),
-                        list(arg = "taxid",
-                             class = "numeric",
-                             max_len = 20),
-                        list(arg = "keyword",
-                             class = "character"),
-                        list(arg = "xref",
-                             class = "character",
-                             max_len = 20),
-                        list(arg = "genome_acc",
-                             class = "character",
-                             max_len = 20),
-                        list(arg = "is_ref_proteome",
-                             class = "logical"),
-                        list(arg = "is_redundant",
-                             class = "logical"))
+  .rba_args(
+    cons = list(
+      list(arg = "upid", class = "character", max_len = 100),
+      list(arg = "name", class = "character"),
+      list(arg = "taxid", class = "numeric", max_len = 20),
+      list(arg = "keyword", class = "character"),
+      list(arg = "xref", class = "character", max_len = 20),
+      list(arg = "genome_acc", class = "character", max_len = 20),
+      list(arg = "is_ref_proteome", class = "logical"),
+      list(arg = "is_redundant", class = "logical")
+    )
   )
 
-  .msg("Searching UniProt and retrieving proteoms that match your supplied inputs.")
-  ## Build GET API Request's query
-  call_query <- .rba_query(init = list("size" = "-1"),
-                           list("name",
-                                !is.null(name),
-                                name),
-                           list("upid",
-                                !is.null(upid),
-                                paste0(upid,
-                                       collapse = ",")),
-                           list("taxid",
-                                !is.null(taxid),
-                                paste0(taxid,
-                                       collapse = ",")),
-                           list("keyword",
-                                !is.null(keyword),
-                                keyword),
-                           list("xref",
-                                !is.null(xref),
-                                paste0(xref,
-                                       collapse = ",")),
-                           list("genome_acc",
-                                !is.null(genome_acc),
-                                paste0(genome_acc,
-                                       collapse = ",")),
-                           list("is_ref_proteome",
-                                !is.null(is_ref_proteome),
-                                ifelse(is_ref_proteome,
-                                       "true",
-                                       "false")),
-                           list("is_redundant",
-                                !is.null(is_redundant),
-                                ifelse(is_redundant,
-                                       "true",
-                                       "false")))
-  ## Build Function-Specific Call
-  parser_input <- list("json->list",
-                       function(x) {
-                         x_names <- vapply(X = x,
-                                          FUN = function(x) {
-                                            x$upid
-                                          },
-                                          FUN.VALUE = character(1))
-                         names(x) <- x_names
-                         return(x)})
+  .msg(
+    "Searching UniProt and retrieving proteoms that match your supplied inputs."
+  )
 
-  input_call <- .rba_httr(httr = "get",
-                          url = .rba_stg("uniprot", "url"),
-                          path = paste0(.rba_stg("uniprot", "pth"),
-                                        "proteomes"),
-                          query = call_query,
-                          accept = "application/json",
-                          parser = parser_input,
-                          save_to = .rba_file("uniprot_proteomes_search.json"))
+  ## Build GET API Request's query
+  call_query <- .rba_query(
+    init = list("size" = "-1"),
+    list("name", !is.null(name), name),
+    list("upid", !is.null(upid), paste0(upid, collapse = ",")),
+    list("taxid", !is.null(taxid), paste0(taxid, collapse = ",")),
+    list("keyword", !is.null(keyword), keyword),
+    list("xref", !is.null(xref), paste0(xref, collapse = ",")),
+    list("genome_acc", !is.null(genome_acc), paste0(genome_acc, collapse = ",")),
+    list("is_ref_proteome", !is.null(is_ref_proteome), ifelse(is_ref_proteome, "true", "false")),
+    list("is_redundant", !is.null(is_redundant), ifelse(is_redundant, "true", "false"))
+  )
+
+  ## Build Function-Specific Call
+  parser_input <- list(
+    "json->list",
+    function(x) {
+      x_names <- vapply(X = x,
+                        FUN = function(x) {
+                          x$upid
+                        },
+                        FUN.VALUE = character(1))
+      names(x) <- x_names
+      return(x)
+    }
+  )
+
+  input_call <- .rba_httr(
+    httr = "get",
+    url = .rba_stg("uniprot", "url"),
+    path = paste0(.rba_stg("uniprot", "pth"), "proteomes"),
+    query = call_query,
+    accept = "application/json",
+    parser = parser_input,
+    save_to = .rba_file("uniprot_proteomes_search.json")
+  )
 
   ## Call API
   final_output <- .rba_skeleton(input_call)
@@ -194,9 +172,9 @@ rba_uniprot_proteomes_search <- function(name = NULL,
 #'   get_proteins argument.
 #'
 #' @references \itemize{
-#'   \item The UniProt Consortium, UniProt: the universal protein
-#'   knowledgebase in 2021, Nucleic Acids Research, Volume 49, Issue D1,
-#'   8 January 2021, Pages D480–D489, https://doi.org/10.1093/nar/gkaa1100
+#'   \item The UniProt Consortium , UniProt: the Universal Protein
+#'   Knowledgebase in 2025, Nucleic Acids Research, 2024;, gkae1010,
+#'   https://doi.org/10.1093/nar/gkae1010
 #'   \item Andrew Nightingale, Ricardo Antunes, Emanuele Alpi, Borisas
 #'   Bursteinas, Leonardo Gonzales, Wudong Liu, Jie Luo, Guoying Qi, Edd
 #'   Turner, Maria Martin, The Proteins API: accessing key integrated protein
@@ -224,54 +202,69 @@ rba_uniprot_proteomes <- function(upid,
                                   ...) {
   ## Load Global Options
   .rba_ext_args(...)
+
   ## Check User-input Arguments
-  .rba_args(cons = list(list(arg = "upid",
-                             class = "character"),
-                        list(arg = "get_proteins",
-                             class = "logical"),
-                        list(arg = "reviewed",
-                             class = "logical")),
-            cond = list(list(quote(isFALSE(get_proteins) && !is.null(reviewed)),
-                             "'reviewed' argument is ignored because you supplied 'get_proteins' as FALSE.")),
-            cond_warning = TRUE
+  .rba_args(
+    cons = list(
+      list(
+        arg = "upid", class = "character"),
+      list(arg = "get_proteins", class = "logical"),
+      list(arg = "reviewed", class = "logical")
+    ),
+    cond = list(
+      list(
+        quote(isFALSE(get_proteins) && !is.null(reviewed)),
+        "'reviewed' argument is ignored because you supplied 'get_proteins' as FALSE."
+      )
+    ),
+    cond_warning = TRUE
+  )
+
+  .msg(
+    "Retrieving proteome %s (%s).",
+    upid,
+    ifelse(
+      isTRUE(get_proteins),
+      yes = sprintf("With %s proteins",
+                    ifelse(
+                      test = is.null(reviewed),
+                      yes = "",
+                      no = ifelse(
+                        test = reviewed,
+                        yes = "only UniProtKB/Swiss-Prot",
+                        no =  "only TrEMBL")
+                    )
+      ),
+      no = "Excluding proteins")
   )
 
-  .msg("Retrieving proteome %s (%s).",
-       upid,
-       ifelse(isTRUE(get_proteins),
-              yes = sprintf("With %s proteins",
-                            ifelse(test = is.null(reviewed),
-                                   yes = "",
-                                   no = ifelse(test = reviewed,
-                                               yes = "only UniProtKB/Swiss-Prot",
-                                               no =  "only TrEMBL"))),
-              no = "Excluding proteins"))
   ## Build Function-Specific Call
   if (isTRUE(get_proteins)) {
+
     ## Build GET API Request's query
-    call_query <- .rba_query(init = list(),
-                             list("reviewed",
-                                  !is.null(reviewed),
-                                  ifelse(reviewed,
-                                         "true",
-                                         "false")))
-    path_input <- paste0(.rba_stg("uniprot", "pth"),
-                         "proteomes/proteins/",
-                         upid)
+    call_query <- .rba_query(
+      init = list(),
+      list("reviewed", !is.null(reviewed), ifelse(reviewed, "true", "false"))
+    )
+
+    path_input <- paste0(.rba_stg("uniprot", "pth"), "proteomes/proteins/", upid)
+
   } else {
+
     call_query <- NULL
-    path_input <- paste0(.rba_stg("uniprot", "pth"),
-                         "proteomes/",
-                         upid)
+    path_input <- paste0(.rba_stg("uniprot", "pth"), "proteomes/", upid)
+
   }
 
-  input_call <- .rba_httr(httr = "get",
-                          url = .rba_stg("uniprot", "url"),
-                          path = path_input,
-                          query = call_query,
-                          accept = "application/json",
-                          parser = "json->list",
-                          save_to = .rba_file("uniprot_proteomes.json"))
+  input_call <- .rba_httr(
+    httr = "get",
+    url = .rba_stg("uniprot", "url"),
+    path = path_input,
+    query = call_query,
+    accept = "application/json",
+    parser = "json->list",
+    save_to = .rba_file("uniprot_proteomes.json")
+  )
 
   ## Call API
   final_output <- .rba_skeleton(input_call)
@@ -313,9 +306,9 @@ rba_uniprot_proteomes <- function(upid,
 #' @return a list containing gene-centric proteins search hits.
 #'
 #' @references \itemize{
-#'   \item The UniProt Consortium, UniProt: the universal protein
-#'   knowledgebase in 2021, Nucleic Acids Research, Volume 49, Issue D1,
-#'   8 January 2021, Pages D480–D489, https://doi.org/10.1093/nar/gkaa1100
+#'   \item The UniProt Consortium , UniProt: the Universal Protein
+#'   Knowledgebase in 2025, Nucleic Acids Research, 2024;, gkae1010,
+#'   https://doi.org/10.1093/nar/gkae1010
 #'   \item Andrew Nightingale, Ricardo Antunes, Emanuele Alpi, Borisas
 #'   Bursteinas, Leonardo Gonzales, Wudong Liu, Jie Luo, Guoying Qi, Edd
 #'   Turner, Maria Martin, The Proteins API: accessing key integrated protein
@@ -346,42 +339,38 @@ rba_uniprot_genecentric_search <- function(upid = NULL,
                                            ...) {
   ## Load Global Options
   .rba_ext_args(...)
+
   ## Check User-input Arguments
-  .rba_args(cons = list(list(arg = "upid",
-                             class = "character",
-                             max_len = 100),
-                        list(arg = "accession",
-                             class = "character",
-                             max_len = 100),
-                        list(arg = "gene",
-                             class = "character",
-                             max_len = 20))
+  .rba_args(
+    cons = list(
+      list(arg = "upid", class = "character", max_len = 100),
+      list(arg = "accession", class = "character", max_len = 100),
+      list(arg = "gene", class = "character", max_len = 20)
+    )
+  )
+
+  .msg(
+    "Searching UniProt and retrieving Gene-Centric Proteins that match your supplied inputs."
   )
 
-  .msg("Searching UniProt and retrieving Gene-Centric Proteins that match your supplied inputs.")
   ## Build GET API Request's query
-  call_query <- .rba_query(init = list("size" = "-1"),
-                           list("upid",
-                                !is.null(upid),
-                                paste0(upid,
-                                       collapse = ",")),
-                           list("accession",
-                                !is.null(accession),
-                                paste0(accession,
-                                       collapse = ",")),
-                           list("gene",
-                                !is.null(gene),
-                                paste0(gene,
-                                       collapse = ",")))
+  call_query <- .rba_query(
+    init = list("size" = "-1"),
+    list("upid", !is.null(upid), paste0(upid, collapse = ",")),
+    list("accession", !is.null(accession), paste0(accession, collapse = ",")),
+    list("gene", !is.null(gene), paste0(gene, collapse = ","))
+  )
+
   ## Build Function-Specific Call
-  input_call <- .rba_httr(httr = "get",
-                          url = .rba_stg("uniprot", "url"),
-                          path = paste0(.rba_stg("uniprot", "pth"),
-                                        "genecentric"),
-                          query = call_query,
-                          accept = "application/json",
-                          parser = "json->list",
-                          save_to = .rba_file("uniprot_genecentric_search.json"))
+  input_call <- .rba_httr(
+    httr = "get",
+    url = .rba_stg("uniprot", "url"),
+    path = paste0(.rba_stg("uniprot", "pth"), "genecentric"),
+    query = call_query,
+    accept = "application/json",
+    parser = "json->list",
+    save_to = .rba_file("uniprot_genecentric_search.json")
+  )
 
   ## Call API
   final_output <- .rba_skeleton(input_call)
@@ -407,9 +396,9 @@ rba_uniprot_genecentric_search <- function(upid = NULL,
 #' @return A list containing information of Gene-Centric proteins.
 #'
 #' @references \itemize{
-#'   \item The UniProt Consortium, UniProt: the universal protein
-#'   knowledgebase in 2021, Nucleic Acids Research, Volume 49, Issue D1,
-#'   8 January 2021, Pages D480–D489, https://doi.org/10.1093/nar/gkaa1100
+#'   \item The UniProt Consortium , UniProt: the Universal Protein
+#'   Knowledgebase in 2025, Nucleic Acids Research, 2024;, gkae1010,
+#'   https://doi.org/10.1093/nar/gkae1010
 #'   \item Andrew Nightingale, Ricardo Antunes, Emanuele Alpi, Borisas
 #'   Bursteinas, Leonardo Gonzales, Wudong Liu, Jie Luo, Guoying Qi, Edd
 #'   Turner, Maria Martin, The Proteins API: accessing key integrated protein
@@ -433,21 +422,26 @@ rba_uniprot_genecentric <- function(accession,
   ## Load Global Options
   .rba_ext_args(...)
   ## Check User-input Arguments
-  .rba_args(cons = list(list(arg = "accession",
-                             class = "character"))
+  .rba_args(
+    cons = list(
+      list(arg = "accession", class = "character")
+    )
+  )
+
+  .msg(
+    "Retrieving Gene-Centric proteins by UniProt Accession %s.",
+    accession
   )
 
-  .msg("Retrieving Gene-Centric proteins by UniProt Accession %s.",
-       accession)
   ## Build Function-Specific Call
-  input_call <- .rba_httr(httr = "get",
-                          url = .rba_stg("uniprot", "url"),
-                          path = paste0(.rba_stg("uniprot", "pth"),
-                                        "genecentric/",
-                                        accession),
-                          accept = "application/json",
-                          parser = "json->list_simp",
-                          save_to = .rba_file("uniprot_genecentric.json"))
+  input_call <- .rba_httr(
+    httr = "get",
+    url = .rba_stg("uniprot", "url"),
+    path = paste0(.rba_stg("uniprot", "pth"), "genecentric/", accession),
+    accept = "application/json",
+    parser = "json->list_simp",
+    save_to = .rba_file("uniprot_genecentric.json")
+  )
 
   ## Call API
   final_output <- .rba_skeleton(input_call)
