@@ -1,4 +1,5 @@
 test_that(".msg works", {
+
   # basics
   verbose <- FALSE
   expect_silent(.msg("test"))
@@ -7,13 +8,13 @@ test_that(".msg works", {
   verbose2 <- FALSE
   expect_silent(.msg("test", cond = "verbose2"))
   # use paste
-  expect_message(object = .msg("1", "2", "3"),
-                 regexp = "123")
+  expect_message(object = .msg("1", "2", "3"), regexp = "123")
   #use sprintf
-  expect_message(object = .msg("1%s%s", "2", "3"),
-                 regexp = "123")
+  expect_message(object = .msg("1%s%s", "2", "3"), regexp = "123")
   #force paste
-  expect_message(object = .msg("1%s%s", "2", "3", sprintf = FALSE),
-                 regexp = "1%s%s23")
+  expect_message(
+    object = .msg("1%s%s", "2", "3", sprintf = FALSE),
+    regexp = "1%s%s23"
+  )
 
 })
